@@ -1,5 +1,5 @@
-//======================================================================
-//-----------------------------------------------------------------------
+/*======================================================================
+----------------------------------------------------------------------*/
 /**
  * @file		iutest_internal_c.h
  * @brief		iris unit test info t@C
@@ -8,91 +8,96 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012 Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013 Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
-//-----------------------------------------------------------------------
-//======================================================================
+/*----------------------------------------------------------------------
+======================================================================*/
 #ifndef INCG_IRIS_iutest_internal_c_H_A3DF31D4_5FC6_4c62_BCF6_EF835E47B10A_
 #define INCG_IRIS_iutest_internal_c_H_A3DF31D4_5FC6_4c62_BCF6_EF835E47B10A_
 
-//======================================================================
-// include
+/* include ===========================================================*/
 #include "../iutest_pred_c.h"
 
-//======================================================================
-// define
-// TestInfo ̕ϐ
-#define IIUTE_C_TEST_BODY_DECL_NAME(testcase_, testname_)	iutest_c_test_body_##testcase_##_##testname_##_
-#define IIUTE_C_TEST_INFO_DECL_NAME(testcase_, testname_)	s_iutest_c_test_info_##testcase_##_##testname_##_
+/* define ============================================================*/
+/**
+ * @private
+ * @{
+*/
+#define IIUT_C_TEST_BODY_DECL_NAME(testcase_, testname_)	iutest_c_test_body_##testcase_##_##testname_##_
+#define IIUT_C_TEST_INFO_DECL_NAME(testcase_, testname_)	s_iutest_c_test_info_##testcase_##_##testname_##_
+#define IIUT_C_TEST_INITIALIZATION_SECTION_NAME(testcase_, testname_)	iutest_c_test_register_dummy_##testcase_##_##testname_
 
-// eXg̒`
+/* eXg̒` */
 #define IIUT_C_TEST_(testcase_, testname_)							\
-	IIUT_C_TEST_ADD_(testcase_, testname_, NULL, NULL, NULL, NULL)
+	IIUT_C_TEST_ADD_(testcase_, testname_, NULL, NULL, NULL, NULL, NULL)
 
-// eXgtBNX`̒`
+/* eXgtBNX`̒` */
 #define IIUT_C_TEST_F_(testfix_, testname_)							\
 	IIUT_C_TEST_ADD_(testfix_, testname_, testfix_.setup_testcase	\
-	, testfix_.teardown_testcase, testfix_.setup, testfix_.teardown)
+	, testfix_.teardown_testcase, testfix_.setup, testfix_.teardown, testfix_.user)
 
 #if IUTEST_C_HAS_MALLOC
 
-#define IIUT_C_TEST_ADD_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_)	\
+#define IIUT_C_TEST_ADD_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, user_)	\
 	IIUT_C_TEST_ADD_I_(testcase_, testname_, setup_testcase_, teardown_testcase_		\
-	, setup_, teardown_, iuUnitTest_AllocTestCase)
+	, setup_, teardown_, user_, iuUnitTest_AllocTestCase)
 
 #else
 
-#define IIUT_C_TEST_ADD_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_)	\
-	static iuTestCase * IUTEST_PP_CAT(iutest_c_alloc_testcase_dummy_, __LINE__)(void) {	\
-	static iuTestCase instance; return &instance; }										\
-	IIUT_C_TEST_ADD_I_(testcase_, testname_, setup_testcase_, teardown_testcase_		\
-	, setup_, teardown_, IUTEST_PP_CAT(iutest_c_alloc_testcase_dummy_, __LINE__))
+#define IIUT_C_TEST_ADD_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, user_)	\
+	static iuTestCase * IUTEST_PP_CAT(iutest_c_alloc_##testcase_##_dummy_, __LINE__)(void) {	\
+	static iuTestCase instance; return &instance; }												\
+	IIUT_C_TEST_ADD_I_(testcase_, testname_, setup_testcase_, teardown_testcase_				\
+	, setup_, teardown_, user_, IUTEST_PP_CAT(iutest_c_alloc_##testcase_##_dummy_, __LINE__))
 
 #endif
 
-#define IIUT_C_TEST_ADD_I_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, allocator_)	\
-	void IIUTE_C_TEST_BODY_DECL_NAME(testcase_, testname_)(void);														\
-	static iuTestInfo IIUTE_C_TEST_INFO_DECL_NAME(testcase_, testname_) = 												\
-	iuTestInfo_ctor(#testname_, IIUTE_C_TEST_BODY_DECL_NAME(testcase_, testname_) );									\
-	IUTEST_C_DECL_INITIALIZATION_SECTION_BEGIN( iutest_c_test_register_dummy_##testcase_##_##testname_ )				\
+#define IIUT_C_TEST_ADD_I_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, user_, allocator_)	\
+	void IIUT_C_TEST_BODY_DECL_NAME(testcase_, testname_)(void);														\
+	static iuTestInfo IIUT_C_TEST_INFO_DECL_NAME(testcase_, testname_) = 												\
+	iuTestInfo_ctor(#testname_, IIUT_C_TEST_BODY_DECL_NAME(testcase_, testname_) );										\
+	IUTEST_C_DECL_INITIALIZATION_SECTION_BEGIN( IIUT_C_TEST_INITIALIZATION_SECTION_NAME(testcase_, testname_) )			\
 	iuTestCase_AddTestInfo(iuUnitTest_AddTestCase(#testcase_, setup_testcase_, teardown_testcase_, allocator_),			\
-	& IIUTE_C_TEST_INFO_DECL_NAME(testcase_, testname_) );																\
-	IIUTE_C_TEST_INFO_DECL_NAME(testcase_, testname_).test.setup = setup_;												\
-	IIUTE_C_TEST_INFO_DECL_NAME(testcase_, testname_).test.teardown = teardown_;										\
+	& IIUT_C_TEST_INFO_DECL_NAME(testcase_, testname_) );																\
+	IIUT_C_TEST_INFO_DECL_NAME(testcase_, testname_).test.setup = setup_;												\
+	IIUT_C_TEST_INFO_DECL_NAME(testcase_, testname_).test.teardown = teardown_;											\
+	IIUT_C_TEST_INFO_DECL_NAME(testcase_, testname_).test.user = user_;											\
 	IUTEST_C_DECL_INITIALIZATION_SECTION_END()																			\
-	void IIUTE_C_TEST_BODY_DECL_NAME(testcase_, testname_)(void)
+	void IIUT_C_TEST_BODY_DECL_NAME(testcase_, testname_)(void)
 
-// p^CYeXg̒`
+#if IUTEST_C_HAS_PARAM_METHOD_TEST
+
+/* p^CYeXg̒` */
 #define IIUT_C_TEST_PMZ_(testcase_, testname_, method_, ...)		\
-	IIUT_C_TEST_PMZ_ADD_(testcase_, testname_, NULL, NULL, NULL, NULL, method_, __VA_ARGS__)
+	IIUT_C_TEST_PMZ_ADD_(testcase_, testname_, NULL, NULL, NULL, NULL, NULL, method_, __VA_ARGS__)
 
-// p^CYeXg eXgtBNX`̒`
+/* p^CYeXg eXgtBNX`̒` */
 #define IIUT_C_TEST_PMZ_F_(testfix_, testname_, method_, ...)			\
 	IIUT_C_TEST_PMZ_ADD_(testfix_, testname_, testfix_.setup_testcase	\
-	, testfix_.teardown_testcase, testfix_.setup, testfix_.teardown, method_, __VA_ARGS__)
+	, testfix_.teardown_testcase, testfix_.setup, testfix_.teardown, testfix_.user, method_, __VA_ARGS__)
 
 #if IUTEST_C_HAS_MALLOC
 
-#define IIUT_C_TEST_PMZ_ADD_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, method_, ...)	\
+#define IIUT_C_TEST_PMZ_ADD_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, user_, method_, ...)	\
 	IIUT_C_TEST_PMZ_ADD_I_(testcase_, testname_, setup_testcase_, teardown_testcase_		\
-	, setup_, teardown_, iuUnitTest_AllocTestCase, method_, __VA_ARGS__)
+	, setup_, teardown_, user_, iuUnitTest_AllocTestCase, method_, __VA_ARGS__)
 
 #else
 
-#define IIUT_C_TEST_PMZ_ADD_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, method_, ...)	\
+#define IIUT_C_TEST_PMZ_ADD_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, user_, method_, ...)	\
 	static iuTestCase * IUTEST_PP_CAT(iutest_c_alloc_testcase_dummy_, __LINE__)(void) {		\
 	static iuTestCase instance; return &instance; }											\
 	IIUT_C_TEST_PMZ_ADD_I_(testcase_, testname_, setup_testcase_, teardown_testcase_		\
-	, setup_, teardown_, IUTEST_PP_CAT(iutest_c_alloc_testcase_dummy_, __LINE__), method_, __VA_ARGS__)
+	, setup_, teardown_, user_, IUTEST_PP_CAT(iutest_c_alloc_testcase_dummy_, __LINE__), method_, __VA_ARGS__)
 
 #endif
 
 #define IIUTE_C_TEST_PMZ_BODY_DECL_NAME(testcase_, testname_)	IUTEST_PP_CAT(iutest_c_test_body_##testcase_##_##testname_##_, __LINE__)
 #define IIUTE_C_TEST_PMZ_INFO_DECL_NAME(testcase_, testname_)	IUTEST_PP_CAT(s_iutest_c_test_info_##testcase_##_##testname_##_, __LINE__)
 
-#define IIUT_C_TEST_PMZ_ADD_I_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, allocator_, method_, ...)	\
+#define IIUT_C_TEST_PMZ_ADD_I_(testcase_, testname_, setup_testcase_, teardown_testcase_, setup_, teardown_, user_, allocator_, method_, ...)	\
 	void IIUTE_C_TEST_PMZ_BODY_DECL_NAME(testcase_, testname_)(void) { method_(__VA_ARGS__); }											\
 	static iuTestInfo IIUTE_C_TEST_PMZ_INFO_DECL_NAME(testcase_, testname_) = 															\
 	iuTestInfo_ctor(#testname_, IIUTE_C_TEST_PMZ_BODY_DECL_NAME(testcase_, testname_) );												\
@@ -101,14 +106,30 @@
 	& IIUTE_C_TEST_PMZ_INFO_DECL_NAME(testcase_, testname_) );																			\
 	IIUTE_C_TEST_PMZ_INFO_DECL_NAME(testcase_, testname_).test.setup = setup_;															\
 	IIUTE_C_TEST_PMZ_INFO_DECL_NAME(testcase_, testname_).test.teardown = teardown_;													\
+	IIUTE_C_TEST_PMZ_INFO_DECL_NAME(testcase_, testname_).test.user = user_;													\
 	IUTEST_C_DECL_INITIALIZATION_SECTION_END()																							\
 
+#endif
+
+/**
+ * @}
+*/
+
+/**
+ * @brief	ASSERT
+*/
+#define IUTEST_ASSERT(cond)	do {	\
+	if( !(cond) ) {					\
+		IUTEST_MESSAGE(#cond, kTestResultFatalFailure);	\
+		exit(1);					\
+	} } while(iuAlwaysZero())
 
 /**
  * @internal
  * @brief	ASSERTION bZ[W
 */
 #define IUTEST_MESSAGE_AT(file_, line_, msg_, result_type_)	iuAssertionHelper_Report(file_, line_, msg_, result_type_)
+#define IUTEST_MESSAGE(msg_, result_type_)					IUTEST_MESSAGE_AT(__FILE__, __LINE__, msg_, result_type_)
 
 /**
  * @internal
@@ -124,7 +145,7 @@
 */
 #define IUTEST_EXPECT_FAILURE(msg)					IUTEST_EXPECT_FAILURE_AT(msg, __FILE__, __LINE__)
 
-#define IUTEST_EXPECT_FAILURE_AT(msg, file, line)	IUTEST_MESSAGE_AT(file, line, msg, kTestResultNotFatalFailure)
+#define IUTEST_EXPECT_FAILURE_AT(msg, file, line)	IUTEST_MESSAGE_AT(file, line, msg, kTestResultNonFatalFailure)
 
 /**
  * @internal
@@ -140,7 +161,7 @@
  * @biref	r؃}N
 */
 #define IUTEST_TEST_ASSERT_(expression, on_failure)	do {	\
-	const iuAssertionResult tr = expression;				\
+	iuAssertionResult tr; tr = (expression);				\
 	if( !tr.result )										\
 		on_failure(tr.message);								\
 	} while(iuAlwaysZero())
@@ -157,6 +178,13 @@
 		on_failure(iuTestAssertion_GetBooleanAssertionFailureMessage(			\
 			text, #actual, #expected) )
 
+
+#define IIUT_SUCCEED()						IUTEST_MESSAGE("Succeeded.\n", kTestResultSuccess)
+#define IIUT_FAIL()							IUTEST_ASSERT_FAILURE("Failed.\n")
+#define IIUT_ADD_FAILURE()					IUTEST_EXPECT_FAILURE("Failed.\n")
+#define IIUT_ADD_FAILURE_AT(file_, line_)	IUTEST_EXPECT_FAILURE_AT("Failed.\n", file_, line_)
+
+
 /**
  * @internal
  * @brief	eXg}N
@@ -200,6 +228,31 @@
 
 #define IUTEST_TEST_SAME(v1, v2, on_failure)			IUTEST_PRED_FORMAT2_( iuTestAssertion_CompHelperSame, v1, v2, on_failure )
 
+
+#define IUTEST_TEST_NO_FATAL_FAILURE_(statement, on_failure)					\
+	if( iuAlwaysTrue() ) {														\
+		const iuTestInfo* pInfo = iuUnitTest_GetCurrentTestInfo();				\
+		const int prevCount = iuTestResult_GetPartCount(&pInfo->result, kTestResultFatalFailure);	\
+		IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING( { (void)0; statement; } );						\
+		if( prevCount < iuTestResult_GetPartCount(&pInfo->result, kTestResultFatalFailure) ) {		\
+			goto IUTEST_PP_CAT(iutest_label_test_no_fatalfailure_, __LINE__);	\
+		}																		\
+	} else																		\
+		IUTEST_PP_CAT(iutest_label_test_no_fatalfailure_, __LINE__):			\
+		on_failure("\nExpected: " #statement " doesn't generate new fatal failure.\n  Actual: it does.")
+
+#define IUTEST_TEST_NO_FAILURE_(statement, on_failure)							\
+	if( iuAlwaysTrue() ) {														\
+		const iuTestInfo* pInfo = iuUnitTest_GetCurrentTestInfo();				\
+		const int prevCount = iuTestResult_FailurePartCount(&pInfo->result);	\
+		IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING( { (void)0; statement; } );	\
+		if( prevCount < iuTestResult_FailurePartCount(&pInfo->result) ) {		\
+			goto IUTEST_PP_CAT(iutest_label_test_no_failure_, __LINE__);		\
+		}																		\
+	} else																		\
+		IUTEST_PP_CAT(iutest_label_test_no_failure_, __LINE__):					\
+		on_failure("\nExpected: " #statement " doesn't generate new fatal failure.\n  Actual: it does.")
+
 /**
  * @}
 */
