@@ -1,5 +1,5 @@
-//======================================================================
-//-----------------------------------------------------------------------
+/*======================================================================
+----------------------------------------------------------------------*/
 /**
  * @file		iutest_pool_c.h
  * @brief		iris unit test memory pool t@C
@@ -8,21 +8,22 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
-//-----------------------------------------------------------------------
-//======================================================================
+/*----------------------------------------------------------------------
+======================================================================*/
 #ifndef INCG_IRIS_iutest_pool_c_H_C6B9E65B_4059_4175_A6DB_397DBF338AA8_
 #define INCG_IRIS_iutest_pool_c_H_C6B9E65B_4059_4175_A6DB_397DBF338AA8_
 
-//======================================================================
-// include
+/* include ===========================================================*/
 #include "../iutest_defs_c.h"
 
-//======================================================================
-// define
+/* declare ===========================================================*/
+static char * iuTest_AllocTestFailureMessageString(size_t length);
+
+/* define ============================================================*/
 #define IUTEST_C_AllocByPool(Result, Type, Count)	do {	\
 	static iuUInt32 flags[(Count+31)/32] = {0};		\
 	static Type results[Count];						\
