@@ -1,5 +1,5 @@
-//======================================================================
-//-----------------------------------------------------------------------
+/*======================================================================
+----------------------------------------------------------------------*/
 /**
  * @file		iutest_time_c.h
  * @brief		iris unit test time utility t@C
@@ -8,25 +8,29 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
-//-----------------------------------------------------------------------
-//======================================================================
+/*----------------------------------------------------------------------
+======================================================================*/
 #ifndef INCG_IRIS_iutest_time_c_H_C6B9E65B_4059_4175_A6DB_397DBF338AA8_
 #define INCG_IRIS_iutest_time_c_H_C6B9E65B_4059_4175_A6DB_397DBF338AA8_
 
-//======================================================================
-// include
+/* include ===========================================================*/
 #include "../iutest_defs_c.h"
 
-#if IUTEST_C_HAS_CTIME || IUTEST_C_HAS_GETTIMEOFDAY || IUTEST_C_HAS_CLOCK
+#if		IUTEST_C_HAS_HDR_TIME
 #  include <time.h>
 #endif
 
-//======================================================================
-// function
+#if		IUTEST_C_HAS_HDR_SYSTIME
+#  include <sys/time.h>
+#elif	defined(IUTEST_OS_WINDOWS) && !defined(IUTEST_OS_WINDOWS_MOBILE)
+#  include <sys/timeb.h>
+#endif
+
+/* function ==========================================================*/
 
 /**
  * @brief	~bbPʂ̕𐶐
@@ -97,9 +101,6 @@ static IUTEST_ATTRIBUTE_UNUSED_ iuTimeInMillisec	iuTest_GetTimeInMillis(void)
 #if		defined(IUTEST_GetMillisec)
 	return IUTEST_GetMillisec();
 
-#elif	defined(IUTEST_OS_WINDOWS)
-	return (iuTimeInMillisec)(GetTickCount());
-
 #elif	IUTEST_C_HAS_GETTIMEOFDAY
 	timeval tv;
 	gettimeofday(&tv, NULL);
@@ -108,6 +109,22 @@ static IUTEST_ATTRIBUTE_UNUSED_ iuTimeInMillisec	iuTest_GetTimeInMillis(void)
 #elif	IUTEST_C_HAS_CLOCK
 	return clock() * 1000 / CLOCKS_PER_SEC;
 
+#elif	defined(IUTEST_OS_WINDOWS)
+
+#if		defined(IUTEST_OS_WINDOWS_MOBILE)
+	return (iuTimeInMillisec)(GetTickCount());
+#else
+
+	struct __timeb64 tb;
+
+IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_BEGIN()
+	_ftime64(&tb);
+IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_END()
+
+	return (iuTimeInMillisec)(tb.time * 1000 + tb.millitm);
+
+#endif
+
 #else
 
 #define IUTEST_C_NO_GETTIMEINMILLIS
@@ -118,14 +135,14 @@ static IUTEST_ATTRIBUTE_UNUSED_ iuTimeInMillisec	iuTest_GetTimeInMillis(void)
 /**
  * @brief	sȒl̎擾
 */
-static IUTEST_ATTRIBUTE_UNUSED_ unsigned int iuTest_GetIndefiniteValue(void)
+static IUTEST_ATTRIBUTE_UNUSED_ iuUInt32 iuTest_GetIndefiniteValue(void)
 {
 #if !defined(IUTEST_C_NO_GETTIMEINMILLIS)
-	return (unsigned int)(iuTest_GetTimeInMillis());
+	return (iuUInt32)(iuTest_GetTimeInMillis());
 #else
-	// ȂׂɂȂȂ悤ɂ
-	static unsigned int s = 20120206;
-	s = s*1664525 + 1013904223;
+	/* ȂׂɂȂȂ悤ɂ */
+	static iuUInt32 s = 20120206u;
+	s = s*1664525u + 1013904223u;
 	return s;
 #endif
 }
@@ -141,7 +158,7 @@ typedef struct iuTestStopWatch_t
 /**
  * @brief	XgbvEHb`̃X^[g
 */
-static void	iuTest_StopWatchStart(iuTestStopWatch* watch)
+static IUTEST_ATTRIBUTE_UNUSED_ void iuTest_StopWatchStart(iuTestStopWatch* watch)
 {
 	watch->begin = iuTest_GetTimeInMillis();
 }
@@ -149,7 +166,7 @@ static void	iuTest_StopWatchStart(iuTestStopWatch* watch)
 /**
  * @brief	XgbvEHb`̒~
 */
-static iuTimeInMillisec	iuTest_StopWatchStop(iuTestStopWatch* watch)
+static IUTEST_ATTRIBUTE_UNUSED_ iuTimeInMillisec iuTest_StopWatchStop(iuTestStopWatch* watch)
 {
 	return iuTest_GetTimeInMillis() - watch->begin;
 }
