@@ -90,7 +90,46 @@
  * @ingroup TESTDEF
  * @brief	eXg𖾎Iɓo^
 */
-#define IUTEST_REIGSTER_TEST(testcase_, testname_)	IUTEST_C_CALL_INITIALIZATION_SECTION(IIUT_C_TEST_INITIALIZATION_SECTION_NAME(testcase_, testname_))
+#define IUTEST_REGISTER_TEST(testcase_, testname_)	IUTEST_C_CALL_INITIALIZATION_SECTION(IIUT_C_TEST_INITIALIZATION_SECTION_NAME(testcase_, testname_))
+
+/**
+ * @defgroup	IUTEST_UTIL		eXgLq⏕
+ * @brief		eXgLq⏕}N
+*/
+
+/**
+ * @ingroup		IUTEST_UTIL
+ * @brief		IȐ
+*/
+#ifndef IUTEST_SUCCEED
+#  define IUTEST_SUCCEED()							IIUT_SUCCEED()
+#endif
+
+/**
+ * @ingroup		IUTEST_UTIL
+ * @brief		IȎs
+*/
+#ifndef IUTEST_FAIL
+#  define IUTEST_FAIL()								IIUT_FAIL()
+#endif
+
+/**
+ * @ingroup		IUTEST_UTIL
+ * @brief		IȎs
+*/
+#ifndef IUTEST_ADD_FAILURE
+#  define IUTEST_ADD_FAILURE()						IIUT_ADD_FAILURE()
+#endif
+
+/**
+ * @ingroup		IUTEST_UTIL
+ * @brief		IȎs
+ * @param		file	= t@CpX
+ * @param		line	= sԍ
+*/
+#ifndef IUTEST_ADD_FAILURE_AT
+#  define IUTEST_ADD_FAILURE_AT(file, line)			IIUT_ADD_FAILURE_AT(file, line)
+#endif
 
 /**
  * @defgroup	IUTEST_ASSERT_	AT[V(ASSERT)
@@ -197,6 +236,8 @@
 #  define	IUTEST_ASSERT_SAME(v1, v2)				IUTEST_TEST_SAME(v1, v2, IUTEST_ASSERT_FAILURE)
 #endif
 
+#if IUTEST_C_HAS_FLOATINGPOINT
+
 /**
  * @ingroup	IUTEST_ASSERT_
  * @brief	float ̔r eXg
@@ -220,6 +261,8 @@
 #  define	IUTEST_ASSERT_NEAR(v1, v2, abs_v)		IUTEST_TEST_NEAR(v1, v2, abs_v, IUTEST_ASSERT_FAILURE)
 #endif
 
+#endif
+
 /**
  * @ingroup	IUTEST_ASSERT_
  * @brief	̈v eXg
@@ -265,6 +308,22 @@
 #  define IUTEST_ASSERT_HRESULT_FAILED(hr)			IUTEST_TEST_HRESULT_FAILED(hr, IUTEST_ASSERT_FAILURE)
 #endif
 
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	no new fatal failure eXg
+*/
+#ifndef IUTEST_ASSERT_NO_FATAL_FAILURE
+#  define IUTEST_ASSERT_NO_FATAL_FAILURE(statement)	IUTEST_TEST_NO_FATAL_FAILURE_(statement, IUTEST_ASSERT_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	no new failure eXg
+*/
+#ifndef IUTEST_ASSERT_NO_FAILURE
+#  define IUTEST_ASSERT_NO_FAILURE(statement)		IUTEST_TEST_NO_FAILURE_(statement, IUTEST_ASSERT_FAILURE)
+#endif
+
 
 /**
  * @defgroup	IUTEST_EXPECT_		AT[V(EXPECT)
@@ -371,6 +430,8 @@
 #  define	IUTEST_EXPECT_SAME(v1, v2)				IUTEST_TEST_SAME(v1, v2, IUTEST_EXPECT_FAILURE)
 #endif
 
+#if IUTEST_C_HAS_FLOATINGPOINT
+
 /**
  * @ingroup	IUTEST_EXPECT_
  * @brief	float ̔r eXg
@@ -394,6 +455,8 @@
 #  define	IUTEST_EXPECT_NEAR(v1, v2, abs_v)		IUTEST_TEST_NEAR(v1, v2, abs_v, IUTEST_EXPECT_FAILURE)
 #endif
 
+#endif
+
 /**
  * @ingroup	IUTEST_EXPECT_
  * @brief	̈v eXg
@@ -439,6 +502,22 @@
 #  define IUTEST_EXPECT_HRESULT_FAILED(hr)			IUTEST_TEST_HRESULT_FAILED(hr, IUTEST_EXPECT_FAILURE)
 #endif
 
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	no new fatal failure eXg
+*/
+#ifndef IUTEST_EXPECT_NO_FATAL_FAILURE
+#  define IUTEST_EXPECT_NO_FATAL_FAILURE(statement)	IUTEST_TEST_NO_FATAL_FAILURE_(statement, IUTEST_EXPECT_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	no new failure eXg
+*/
+#ifndef IUTEST_EXPECT_NO_FAILURE
+#  define IUTEST_EXPECT_NO_FAILURE(statement)		IUTEST_TEST_NO_FAILURE_(statement, IUTEST_EXPECT_FAILURE)
+#endif
+
 
 /**
  * @defgroup	IUTEST_INFORM_		AT[V(INFORM)
@@ -545,6 +624,8 @@
 #  define	IUTEST_INFORM_SAME(v1, v2)				IUTEST_TEST_SAME(v1, v2, IUTEST_INFORM_FAILURE)
 #endif
 
+#if IUTEST_C_HAS_FLOATINGPOINT
+
 /**
  * @ingroup	IUTEST_INFORM_
  * @brief	float ̔r eXg
@@ -568,6 +649,8 @@
 #  define	IUTEST_INFORM_NEAR(v1, v2, abs_v)		IUTEST_TEST_NEAR(v1, v2, abs_v, IUTEST_INFORM_FAILURE)
 #endif
 
+#endif
+
 /**
  * @ingroup	IUTEST_INFORM_
  * @brief	̈v eXg
@@ -613,8 +696,25 @@
 #  define IUTEST_INFORM_HRESULT_FAILED(hr)			IUTEST_TEST_HRESULT_FAILED(hr, IUTEST_INFORM_FAILURE)
 #endif
 
+/**
+ * @ingroup	IUTEST_INFORM_
+ * @brief	no new fatal failure eXg
+*/
+#ifndef IUTEST_INFORM_NO_FAILURE
+#  define IUTEST_INFORM_NO_FAILURE(statement)		IUTEST_TEST_NO_FAILURE_(statement, IUTEST_INFORM_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_INFORM_
+ * @brief	no new failure eXg
+*/
+#ifndef IUTEST_INFORM_NO_FATAL_FAILURE
+#  define IUTEST_INFORM_NO_FATAL_FAILURE(statement)	IUTEST_TEST_NO_FATAL_FAILURE_(statement, IUTEST_INFORM_FAILURE)
+#endif
+
+
 /* declare ===========================================================*/
-static void			iuTestInitialize(void);
+static void iuTestInitialize(void);
 
 /* function ==========================================================*/
 /**
@@ -648,7 +748,7 @@ static IUTEST_ATTRIBUTE_UNUSED_ void	iuInitIrisUnitTestW(int* argc, wchar_t** ar
 /**
  * @biref	eXg̏iʍj
 */
-static void			iuTestInitialize(void)
+static void iuTestInitialize(void)
 {
 	{
 		iuTestListener* listener = iuTestListener_MakeListener(&iuUnitTest_GetInstance()->def_printer
