@@ -54,10 +54,14 @@ typedef enum IUTESTENV_FLAG
 	IUTESTENV_FLAG_DEFAULT			= 0
 } IUTESTENV_FLAG;
 
+/* declare ===========================================================*/
+struct iuTestPartResult_t;
+
 /* typedef ===========================================================*/
 typedef int (*iuVPrintf)(const char* fmt, va_list va);
 typedef void (*iuGlobalEnvironmentSetUp)(void);
 typedef void (*iuGlobalEnvironmentTearDown)(void);
+typedef iuBOOL (*iuTestCommitTestPartResult)(struct iuTestPartResult_t* part_result, void* user);
 
 /* struct ============================================================*/
 /**
@@ -78,6 +82,15 @@ typedef struct iuTestGlobalEnvTearDown_t
 	struct iuTestGlobalEnvTearDown_t*	next;	/*!< ̍\ */
 } iuTestGlobalEnvTearDown;
 
+/**
+ * @brief	ʂ̓o^R[obN֐
+*/
+typedef struct iuTestCommitPartResultInfo_t
+{
+	iuTestCommitTestPartResult func;
+	void* user;
+} iuTestCommitPartResultInfo;
+
 /**
  * @brief	eXg\
 */
@@ -86,6 +99,7 @@ typedef struct iuTestEnv_t
 	iuTestListener*	listeners;		/*!< Xi[Xg */
 	iuTestGlobalEnvSetUp*		env_setup;		/*!< O[o SetUp Xg */
 	iuTestGlobalEnvTearDown*	env_teardown;	/*!< O[o TearDown Xg */
+	iuTestCommitPartResultInfo	commit_result;	/*!< eXgʂ̓o^R[obN֐ */
 	iuUInt32		flag;			/*!< tO */
 	iuUInt32		current_seed;	/*!< V[ȟݒl */
 	iuRandomContext	random_context;	/*!< ReLXg */
@@ -110,8 +124,8 @@ typedef struct iuTestEnv_t
  * @{
 */
 #define iuTestEnvOption_ctor()	{ NULL, 1, 0, FALSE, TRUE, FALSE, FALSE }
-#define iuTestEnv_ctor()	{ NULL, NULL, NULL, IUTESTENV_FLAG_DEFAULT, 0, iuRandomContext_ctor()	\
-								, iuTestEnvOption_ctor(), NULL, {0} }
+#define iuTestEnv_ctor()	{ NULL, NULL, NULL, { NULL, NULL }, IUTESTENV_FLAG_DEFAULT, 0		\
+								, iuRandomContext_ctor(), iuTestEnvOption_ctor(), NULL, {0} }
 /**
  * @}
 */
