@@ -1,5 +1,5 @@
-//======================================================================
-//-----------------------------------------------------------------------
+/*======================================================================
+----------------------------------------------------------------------*/
 /**
  * @file		iutest_static_assertion_c.h
  * @brief		iris unit test static assertion ` t@C
@@ -8,25 +8,21 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
-//-----------------------------------------------------------------------
-//======================================================================
+/*----------------------------------------------------------------------
+======================================================================*/
 #ifndef INCG_IRIS_iutest_static_assertion_C_H_53842FD6_9E5D_40a6_905D_EC6DEBE5ED6A_
 #define INCG_IRIS_iutest_static_assertion_C_H_53842FD6_9E5D_40a6_905D_EC6DEBE5ED6A_
 
-//======================================================================
-// include
-
-//======================================================================
-// define
+/* define ============================================================*/
 /**
  * @brief	static_assert
 */
 #define IUTEST_STATIC_ASSERT_MSG(B, Msg)	\
-	typedef char IUTEST_PP_CAT(static_assert_typedef_, __LINE__)[(iuBOOL)( B ) ? 1 : -1]
+	typedef char IUTEST_PP_CAT(IUTEST_PP_CAT(static_assert_typedef_, __LINE__),IUTEST_PP_COUNTER)[(iuBOOL)( B ) ? 1 : -1]
 
 /**
  * @brief	static_assert
