@@ -1,5 +1,5 @@
-//======================================================================
-//-----------------------------------------------------------------------
+/*======================================================================
+----------------------------------------------------------------------*/
 /**
  * @file		iutest_ver_c.h
  * @brief		iris unit test version ` t@C
@@ -8,25 +8,21 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012 Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
-//-----------------------------------------------------------------------
-//======================================================================
+/*----------------------------------------------------------------------
+======================================================================*/
 #ifndef INCG_IRIS_iutest_ver_C_H_D65CB7A7_D2AD_40fe_8F5F_8FBF376A0010_
 #define INCG_IRIS_iutest_ver_C_H_D65CB7A7_D2AD_40fe_8F5F_8FBF376A0010_
 
-//======================================================================
-// include
-
-//======================================================================
-// define
-#define	IUTEST_C_VER			0x00060201	//!< iutest version 0.6.2.1
-#define IUTEST_C_MAJORVER		0x00		//!< Major Version
-#define IUTEST_C_MINORVER		0x06		//!< Minor Version
-#define IUTEST_C_BUILD			0x02		//!< Build
-#define IUTEST_C_REVISION		0x01		//!< Revision
+/* define ============================================================*/
+#define	IUTEST_C_VER			0x01030000	/*!< iutest version 1.3.0.0 */
+#define IUTEST_C_MAJORVER		0x01		/*!< Major Version */
+#define IUTEST_C_MINORVER		0x03		/*!< Minor Version */
+#define IUTEST_C_BUILD			0x00		/*!< Build */
+#define IUTEST_C_REVISION		0x00		/*!< Revision */
 
 /**
  * @mainpage
@@ -34,7 +30,7 @@
  *			sourceforge : http://sourceforge.jp/projects/iutest/ \n
  *
  * @par		copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  *
  * @par		LICENSE
@@ -86,9 +82,60 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
 /**
- * @page	RELEASE		[Xm[g
- * @par		release note
+ * @page	CHANGELOG		ύX
+ * @par		Changes
 <ul>
+  <li>v1.3.0.0
+    <ul>
+      <li>IUTEST_*_FATAL_FAILURE, IUTEST_*_NON_FATAL_FAILURE ǉ</li>
+      <li>l̃p[^eXg̖Io^ɑΉ(IUTEST_REIGSTER_TEST_P)</li>
+      <li>p[^̑gݍ킹(fJg)eXg𐶐 iuCombine ǉ</li>
+      <li>IUTEST_*_NO_FATAL_FAILURE, IUTEST_*_NO_FAILURE ǉ</li>
+      <li>IȐƎsɑΉ</li>
+    </ul>
+  </li>
+  <li>v1.2.0.0
+    <ul>
+      <li>l̃p[^eXgɑΉ</li>
+    </ul>
+  </li>
+  <li>v1.1.0.0
+    <ul>
+      <li>CurhΉ</li>
+    </ul>
+  </li>
+  <li>v1.0.1.1
+    <ul>
+      <li>eXgtBNX`oRŃ[U[f[^ێł悤ɏC</li>
+      <li>IvV̊ϐ IUTEST_C n܂閼OɕύX</li>
+    </ul>
+  </li>
+  <li>v1.0.0.0
+    <ul>
+      <li>[X</li>
+      <li>AT[VŎsꍇɎs̒lo͂悤ɕύX</li>
+    </ul>
+  </li>
+  <li>v0.9.3.0
+    <ul>
+      <li>ϐɑΉ</li>
+      <li>O[o SetUp - TearDown ɑΉ</li>
+      <li>IUTEST_STATIC_ASSERT ǉ</li>
+      <li>qtH[}bg INFORM ɑΉĂȂ̂ŏC</li>
+      <li>C90 Ή</li>
+    </ul>
+  </li>
+  <li>v0.8.0.0
+    <ul>
+      <li>eXg֐̎WɑΉĂȂpɖIȓo^}Nǉ</li>
+      <li>o͊֐|C^ݒł悤ɏC</li>
+    </ul>
+  </li>
+  <li>v0.7.0.0
+    <ul>
+      <li>rhG[C</li>
+    </ul>
+  </li>
   <li>v0.6.2.1
     <ul>
       <li>p^CYeXgΉ</li>
@@ -129,9 +176,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   </li>
   <li>v0.1.0.0
     <ul>
-	  <li>{IȃeXg̍쐬ɑΉ</li>
-	  <li>eXg̃tB^OɑΉ</li>
-	</ul>
+      <li>{IȃeXg̍쐬ɑΉ</li>
+      <li>eXg̃tB^OɑΉ</li>
+    </ul>
   </li>
 </ul>
 */
