@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -17,7 +17,6 @@
 
 /* include ===========================================================*/
 #include "../include/iutest_c.h"
-#include <assert.h>
 
 IUTEST_C_WORKSPACE();
 
@@ -64,12 +63,12 @@ int main(int argc, char* argv[])
 	iuUnitTest_AddGlobalEnvironmentTearDown(GlobalTearDown2);
 	
 	IUTEST_INIT(&argc, argv);
-	assert( call_setup == 0 );
-	assert( call_teardown == 0 );
+	IUTEST_ASSERT( call_setup == 0 );
+	IUTEST_ASSERT( call_teardown == 0 );
 	
-	ret = IUTEST_RUN_ALL_TESTS();	// run all
+	ret = IUTEST_RUN_ALL_TESTS();
 
-	assert( call_teardown == 2 );
+	IUTEST_ASSERT( call_teardown == 2 );
 
 	if( ret == 0 )
 	{
