@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -26,18 +26,19 @@ IUTEST(Foo, NotRun)
 }
 
 #ifdef UNICODE
-int wmain(int argc, wchar_t* argv[])
+int wmain(int argc, wchar_t** argv)
 #else
-int main(int argc, char* argv[])
+int main(int argc, char** argv)
 #endif
 {
 	int targc = 2;
+	char* cmd = "--help";
 	char* targv[] = {
 		argv[0]
-		, "--help"
+		, cmd
 	};
 	(void)argc;
 	IUTEST_INIT(&targc, targv);
-	return IUTEST_RUN_ALL_TESTS();	// run all
+	return IUTEST_RUN_ALL_TESTS();
 }
 
